
if (CMAKE_VERSION VERSION_LESS 2.8.3)
    message(FATAL_ERROR "Qt 5 requires at least CMake version 2.8.3")
endif()

get_filename_component(_qt5ScriptTools_install_prefix "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

# For backwards compatibility only. Use Qt5ScriptTools_VERSION instead.
set(Qt5ScriptTools_VERSION_STRING 5.7.0)

set(Qt5ScriptTools_LIBRARIES Qt5::ScriptTools)

macro(_qt5_ScriptTools_check_file_exists file)
    if(NOT EXISTS "${file}" )
        message(FATAL_ERROR "The imported target \"Qt5::ScriptTools\" references the file
   \"${file}\"
but this file does not exist.  Possible reasons include:
* The file was deleted, renamed, or moved to another location.
* An install or uninstall procedure did not complete successfully.
* The installation package was faulty and contained
   \"${CMAKE_CURRENT_LIST_FILE}\"
but not all the files it references.
")
    endif()
endmacro()

macro(_populate_ScriptTools_target_properties Configuration LIB_LOCATION IMPLIB_LOCATION)
    set_property(TARGET Qt5::ScriptTools APPEND PROPERTY IMPORTED_CONFIGURATIONS ${Configuration})

    if(USE_STATIC_QT_BUILD)
        set(imported_location "${_qt5ScriptTools_install_prefix}/lib/${LIB_LOCATION}")
    else()
        set(imported_location "${_qt5ScriptTools_install_prefix}/bin/${LIB_LOCATION}")
    endif()
    _qt5_ScriptTools_check_file_exists(${imported_location})
    if (_Qt5ScriptTools_LIB_DEPENDENCIES)
        set(_list_sep ";")
    endif()
    set_target_properties(Qt5::ScriptTools PROPERTIES
        "INTERFACE_LINK_LIBRARIES_${Configuration}" "${_Qt5ScriptTools_LIB_DEPENDENCIES}${_list_sep}${_Qt5ScriptTools_STATIC_${Configuration}_LIB_DEPENDENCIES}"
        "IMPORTED_LOCATION_${Configuration}" ${imported_location}
        # For backward compatibility with CMake < 2.8.12
        "IMPORTED_LINK_INTERFACE_LIBRARIES_${Configuration}" "${_Qt5ScriptTools_LIB_DEPENDENCIES}${_list_sep}${_Qt5ScriptTools_STATIC_${Configuration}_LIB_DEPENDENCIES}"
    )

    set(imported_implib "${_qt5ScriptTools_install_prefix}/lib/${IMPLIB_LOCATION}")
    _qt5_ScriptTools_check_file_exists(${imported_implib})
    if(NOT "${IMPLIB_LOCATION}" STREQUAL "")
        set_target_properties(Qt5::ScriptTools PROPERTIES
        "IMPORTED_IMPLIB_${Configuration}" ${imported_implib}
        )
    endif()
endmacro()

if (NOT TARGET Qt5::ScriptTools)

    set(_Qt5ScriptTools_OWN_INCLUDE_DIRS "${_qt5ScriptTools_install_prefix}/include/qt/" "${_qt5ScriptTools_install_prefix}/include/qt/QtScriptTools")
    set(Qt5ScriptTools_PRIVATE_INCLUDE_DIRS "")
    include("${CMAKE_CURRENT_LIST_DIR}/ExtraSourceIncludes.cmake" OPTIONAL)

    foreach(_dir ${_Qt5ScriptTools_OWN_INCLUDE_DIRS})
        _qt5_ScriptTools_check_file_exists(${_dir})
    endforeach()

    # Only check existence of private includes if the Private component is
    # specified.
    list(FIND Qt5ScriptTools_FIND_COMPONENTS Private _check_private)
    if (NOT _check_private STREQUAL -1)
        foreach(_dir ${Qt5ScriptTools_PRIVATE_INCLUDE_DIRS})
            _qt5_ScriptTools_check_file_exists(${_dir})
        endforeach()
    endif()

    set(Qt5ScriptTools_INCLUDE_DIRS ${_Qt5ScriptTools_OWN_INCLUDE_DIRS})

    set(Qt5ScriptTools_DEFINITIONS -DQT_SCRIPTTOOLS_LIB)
    set(Qt5ScriptTools_COMPILE_DEFINITIONS QT_SCRIPTTOOLS_LIB)
    set(_Qt5ScriptTools_MODULE_DEPENDENCIES "Core")


    set(_Qt5ScriptTools_FIND_DEPENDENCIES_REQUIRED)
    if (Qt5ScriptTools_FIND_REQUIRED)
        set(_Qt5ScriptTools_FIND_DEPENDENCIES_REQUIRED REQUIRED)
    endif()
    set(_Qt5ScriptTools_FIND_DEPENDENCIES_QUIET)
    if (Qt5ScriptTools_FIND_QUIETLY)
        set(_Qt5ScriptTools_DEPENDENCIES_FIND_QUIET QUIET)
    endif()
    set(_Qt5ScriptTools_FIND_VERSION_EXACT)
    if (Qt5ScriptTools_FIND_VERSION_EXACT)
        set(_Qt5ScriptTools_FIND_VERSION_EXACT EXACT)
    endif()

    set(Qt5ScriptTools_EXECUTABLE_COMPILE_FLAGS "")

    foreach(_module_dep ${_Qt5ScriptTools_MODULE_DEPENDENCIES})
        if (NOT Qt5${_module_dep}_FOUND)
            find_package(Qt5${_module_dep}
                5.7.0 ${_Qt5ScriptTools_FIND_VERSION_EXACT}
                ${_Qt5ScriptTools_DEPENDENCIES_FIND_QUIET}
                ${_Qt5ScriptTools_FIND_DEPENDENCIES_REQUIRED}
                PATHS "${CMAKE_CURRENT_LIST_DIR}/.." NO_DEFAULT_PATH
            )
        endif()

        if (NOT Qt5${_module_dep}_FOUND)
            set(Qt5ScriptTools_FOUND False)
            return()
        endif()

        list(APPEND Qt5ScriptTools_INCLUDE_DIRS "${Qt5${_module_dep}_INCLUDE_DIRS}")
        list(APPEND Qt5ScriptTools_PRIVATE_INCLUDE_DIRS "${Qt5${_module_dep}_PRIVATE_INCLUDE_DIRS}")
        list(APPEND Qt5ScriptTools_DEFINITIONS ${Qt5${_module_dep}_DEFINITIONS})
        list(APPEND Qt5ScriptTools_COMPILE_DEFINITIONS ${Qt5${_module_dep}_COMPILE_DEFINITIONS})
        list(APPEND Qt5ScriptTools_EXECUTABLE_COMPILE_FLAGS ${Qt5${_module_dep}_EXECUTABLE_COMPILE_FLAGS})
    endforeach()
    list(REMOVE_DUPLICATES Qt5ScriptTools_INCLUDE_DIRS)
    list(REMOVE_DUPLICATES Qt5ScriptTools_PRIVATE_INCLUDE_DIRS)
    list(REMOVE_DUPLICATES Qt5ScriptTools_DEFINITIONS)
    list(REMOVE_DUPLICATES Qt5ScriptTools_COMPILE_DEFINITIONS)
    list(REMOVE_DUPLICATES Qt5ScriptTools_EXECUTABLE_COMPILE_FLAGS)

    set(_Qt5ScriptTools_LIB_DEPENDENCIES "Qt5::Core")


    if(USE_STATIC_QT_BUILD)
        add_library(Qt5::ScriptTools STATIC IMPORTED)
        set_property(TARGET Qt5::ScriptTools PROPERTY IMPORTED_LINK_INTERFACE_LANGUAGES CXX)

        macro(macro_process_prl_file prl_file_location Configuration)
            if (EXISTS "${prl_file_location}")
                file(STRINGS "${prl_file_location}" prl_strings REGEX "QMAKE_PRL_LIBS_FOR_CMAKE")
                string(REGEX REPLACE "QMAKE_PRL_LIBS_FOR_CMAKE *= *([^\n]*)" "\\1" static_depends ${prl_strings})
                string(REGEX REPLACE "\\$\\$\\[QT_INSTALL_LIBS\\]" "${_qt5ScriptTools_install_prefix}/lib" static_depends "${static_depends}")
                if (_Qt5ScriptTools_STATIC_${Configuration}_LIB_DEPENDENCIES)
                    set(_list_sep ";")
                endif()
                set(_Qt5ScriptTools_STATIC_${Configuration}_LIB_DEPENDENCIES "${_Qt5ScriptTools_STATIC_${Configuration}_LIB_DEPENDENCIES}${_list_sep}${static_depends}")
            endif()
        endmacro()

        macro(macro_process_plugin_prl_file prl_file_location Configuration LIB_DIRECTORY LIB_LOCATION)
            # First add the (static) plugin itself ...
            if (_Qt5ScriptTools_STATIC_${Configuration}_LIB_DEPENDENCIES)
                set(_list_sep ";")
            endif()
            set(_Qt5ScriptTools_STATIC_${Configuration}_LIB_DEPENDENCIES "${_Qt5ScriptTools_STATIC_${Configuration}_LIB_DEPENDENCIES}${_list_sep}${_qt5ScriptTools_install_prefix}/${LIB_DIRECTORY}/${LIB_LOCATION}")
            # .. then its dependencies.
            macro_process_prl_file(${prl_file_location} ${Configuration})
        endmacro()

        macro_process_prl_file("${_qt5ScriptTools_install_prefix}/lib/Qt5ScriptToolsd-static.prl" DEBUG)
        macro_process_prl_file("${_qt5ScriptTools_install_prefix}/lib/Qt5ScriptTools-static.prl" RELEASE)
    else()
        add_library(Qt5::ScriptTools SHARED IMPORTED)
    endif()


    set_property(TARGET Qt5::ScriptTools PROPERTY
      INTERFACE_INCLUDE_DIRECTORIES ${_Qt5ScriptTools_OWN_INCLUDE_DIRS})
    set(interface_compile_definitions QT_SCRIPTTOOLS_LIB)
    if(USE_STATIC_QT_BUILD)
        set_property(TARGET Qt5::ScriptTools PROPERTY
            INTERFACE_COMPILE_DEFINITIONS QT_STATIC;QT_DESIGNER_STATIC QT_SCRIPTTOOLS_LIB)
    else()
        set_property(TARGET Qt5::ScriptTools PROPERTY
            INTERFACE_COMPILE_DEFINITIONS QT_SCRIPTTOOLS_LIB)
    endif()
    if(USE_STATIC_QT_BUILD)
        file(GLOB pluginTargetsMaybe "${CMAKE_CURRENT_LIST_DIR}/StaticQt5ScriptTools_*.cmake")
    else()
        file(GLOB pluginTargetsMaybe "${CMAKE_CURRENT_LIST_DIR}/Qt5ScriptTools_*.cmake")
    endif()
    unset(pluginTargets)
    if (pluginTargetsMaybe)
        foreach(pluginTarget ${pluginTargetsMaybe})
            file(STRINGS ${pluginTarget} matched REGEX Qt5ScriptTools_PLUGINS)
            if (matched)
                list(APPEND pluginTargets ${pluginTarget})
            endif()
        endforeach()
    endif()

    macro(_populate_ScriptTools_plugin_properties Plugin Configuration PLUGIN_LOCATION)
        set_property(TARGET Qt5::${Plugin} APPEND PROPERTY IMPORTED_CONFIGURATIONS ${Configuration})

        set(imported_location "${_qt5ScriptTools_install_prefix}/lib/qt/plugins/${PLUGIN_LOCATION}")
        _qt5_ScriptTools_check_file_exists(${imported_location})
        set_target_properties(Qt5::${Plugin} PROPERTIES
            "IMPORTED_LOCATION_${Configuration}" ${imported_location}
        )
        if(USE_STATIC_QT_BUILD)
            set_property(TARGET Qt5::ScriptTools APPEND PROPERTY STATIC_PLUGINS ${Plugin})
            get_filename_component(_plugindir ${PLUGIN_LOCATION} PATH)
            get_filename_component(_plugindirname ${_plugindir} NAME)
            get_filename_component(_pluginname ${PLUGIN_LOCATION} NAME)
            string(REGEX REPLACE "^lib(.*)\\.a" "${_qt5ScriptTools_install_prefix}/lib/qt/plugins/${_plugindirname}/\\1-static.prl" plugin_prl_file_location ${_pluginname})
            macro_process_plugin_prl_file(${plugin_prl_file_location} ${Configuration} "lib/qt/plugins" ${PLUGIN_LOCATION})
        endif()

    endmacro()

    if (pluginTargets)
        foreach(pluginTarget ${pluginTargets})
            include(${pluginTarget})
        endforeach()
    endif()

    if(USE_STATIC_QT_BUILD)
        _populate_ScriptTools_target_properties(RELEASE "libQt5ScriptTools.a" "" )
    else()
    _populate_ScriptTools_target_properties(RELEASE "Qt5ScriptTools.dll" "libQt5ScriptTools.dll.a" )
    endif()


    if(USE_STATIC_QT_BUILD)
        if (EXISTS "${_qt5ScriptTools_install_prefix}/lib/libQt5ScriptToolsd.a" )
            _populate_ScriptTools_target_properties(DEBUG "libQt5ScriptToolsd.a" "" )
        endif()
    else()
    if (EXISTS
        "${_qt5ScriptTools_install_prefix}/bin/Qt5ScriptToolsd.dll"
    AND EXISTS
        "${_qt5ScriptTools_install_prefix}/lib/libQt5ScriptToolsd.dll.a" )
        _populate_ScriptTools_target_properties(DEBUG "Qt5ScriptToolsd.dll" "libQt5ScriptToolsd.dll.a" )
    endif()
    endif()





_qt5_ScriptTools_check_file_exists("${CMAKE_CURRENT_LIST_DIR}/Qt5ScriptToolsConfigVersion.cmake")

endif()
